@@ -16,11 +16,11 @@ class Settings:
 
     def append(self, name_value_type_token:tuple):
         assert isinstance(name_value_type_token, tuple), "A tuple of symbol name, value_type, and symbol_handler_token must be provided."
-        assert name_value_type_token not in self.name_value_type_token, f"Tuple: {name_value_type_token} already exist. Choose a different symbol name."
+        assert name_value_type_token not in self.name_value_type_token, f"Symbol {name_value_type_token} already exists in a SymbolsHandler instance. Can not be loaded again."
         self.name_value_type_token[name_value_type_token] = True
 
     def exists(self, name_value_type_token:tuple):
-        assert isinstance(name_value_type_token, tuple), "A tuple of symbol name, value_type, and symbol_handler_token must be provided."
+        assert isinstance(name_value_type_token, tuple), "Symbol name, value_type, and symbol_handler_token must be provided."
         if name_value_type_token in self.name_value_type_token:
             return True
         else:
